@@ -10,8 +10,6 @@ class TestDecorator(unittest.TestCase):
             def _tt(self):
                 pass
         b = TestBot()
-        print(b.funcs)
-        print(b.funcs[0]['options']['callback'])
         self.assertEqual(True, callable(b.funcs[0]['options']['callback']))
 
     def test_timer_noarg(self):
@@ -20,8 +18,6 @@ class TestDecorator(unittest.TestCase):
             def _test_timer_noarg(self):
                 pass
         bb = TestTimerNoargBot()
-        print(bb.funcs)
-        print(bb.funcs[0]['options']['callback'])
         self.assertEqual(True, callable(bb.funcs[0]['options']['callback']))
 
 
